summaryrefslogtreecommitdiff
path: root/vcl/inc/unx/gtk/gtksalmenu.hxx
diff options
context:
space:
mode:
authorAntonio Fernandez <antonio.fernandez@aentos.es>2012-08-16 22:48:54 +0100
committerBjoern Michaelsen <bjoern.michaelsen@canonical.com>2012-11-14 13:52:42 +0100
commitbd777c0952266a988001d2008117b3b5cbf9d091 (patch)
treecc8a3b6e18e85dc8077d1b3a902d75f1a110c606 /vcl/inc/unx/gtk/gtksalmenu.hxx
parentbbd5e6acb0da1382644e6e39bdd7ca6e96a6d715 (diff)
GLOActionGroup partially implemented. Menus work but no special items shown.
Change-Id: I7c48fbc5763daf789e7347cfedc62f14be53c934
Diffstat (limited to 'vcl/inc/unx/gtk/gtksalmenu.hxx')
-rw-r--r--vcl/inc/unx/gtk/gtksalmenu.hxx19
1 files changed, 11 insertions, 8 deletions
diff --git a/vcl/inc/unx/gtk/gtksalmenu.hxx b/vcl/inc/unx/gtk/gtksalmenu.hxx
index 3bffc6c2f8e7..d5ee38f46e4f 100644
--- a/vcl/inc/unx/gtk/gtksalmenu.hxx
+++ b/vcl/inc/unx/gtk/gtksalmenu.hxx
@@ -98,6 +98,7 @@ public:
virtual GMenuModel* GetCurrentSection() { return mpCurrentSection; }
virtual unsigned GetItemCount() { return maItems.size(); }
virtual GtkSalMenuItem* GetItemAtPos( unsigned nPos ) { return maItems[ nPos ]; }
+ virtual GActionGroup* GetActionGroup() { return mpActionGroup; }
};
class GtkSalMenuItem : public SalMenuItem
@@ -106,14 +107,16 @@ public:
GtkSalMenuItem( const SalItemParams* );
virtual ~GtkSalMenuItem();
- sal_uInt16 mnId; // Item ID
- sal_uInt16 mnPos; // Item position
- Menu* mpVCLMenu; // VCL Menu into which this MenuItem is inserted
- GtkSalMenu* mpParentMenu; // The menu in which this menu item is inserted
- GtkSalMenu* mpSubMenu; // Sub menu of this item (if defined)
- GMenuModel* mpParentSection; // Section where this item is added.
- GLOMenuItem* mpMenuItem; // The GMenuItem
- GAction* mpAction; // The GAction associated with this item
+ sal_uInt16 mnId; // Item ID
+ sal_uInt16 mnPos; // Item position
+ gchar* maCommand; // Item command
+ Menu* mpVCLMenu; // VCL Menu into which this MenuItem is inserted
+ GtkSalMenu* mpParentMenu; // The menu in which this menu item is inserted
+ GtkSalMenu* mpSubMenu; // Sub menu of this item (if defined)
+ GMenuModel* mpParentSection; // Section where this item is added.
+ GLOMenuItem* mpMenuItem; // The GMenuItem
+ GVariantType* mpStateType; // A GVariantType with item state type
+ GVariant* mpState; // A GVariant with current item state
};
#endif // GTKSALMENU_HXX